@@ -23,7 +23,10 @@ generic type system of any library without undue effort.
 !*/
 
 use crate::{
-	index::BitIdx,
+	index::{
+		BitIdx,
+		BitRegister,
+	},
 	mem::BitMemory,
 	order::BitOrder,
 	pointer::BitPtr,
@@ -119,7 +122,7 @@ pub trait BitView {
 
 #[cfg(not(tarpaulin_include))]
 impl<T> BitView for T
-where T: BitStore + BitMemory
+where T: BitStore + BitRegister
 {
 	type Mem = T::Mem;
 	type Store = Self;
@@ -145,7 +148,7 @@ where T: BitStore + BitMemory
 
 #[cfg(not(tarpaulin_include))]
 impl<T> BitView for [T]
-where T: BitStore + BitMemory
+where T: BitStore + BitRegister
 {
 	type Mem = T::Mem;
 	type Store = T;
@@ -345,7 +348,7 @@ where T: BitStore
 impl<A, T> AsBits<T> for A
 where
 	A: AsRef<[T]>,
-	T: BitStore + BitMemory,
+	T: BitStore + BitRegister,
 {
 	#[inline]
 	fn as_bits<O>(&self) -> &BitSlice<O, T>
@@ -358,7 +361,7 @@ where
 impl<A, T> AsBitsMut<T> for A
 where
 	A: AsMut<[T]>,
-	T: BitStore + BitMemory,
+	T: BitStore + BitRegister,
 {
 	#[inline]
 	fn as_bits_mut<O>(&mut self) -> &mut BitSlice<O, T>
